;Filename: ClkPow.s
;Part: ADuC702x.
;Created: 11/03/2004 at 11h58
;Updated: 28/06/2005
;Author: Eckart Hartmann.
;This file is in beta sampling.

#include        <ADuC702x.IAR.equ>

; ClkPow==========Sets a powerdown mode for the part.
; C Function prototype: int ClkPow(int iPC);
;iPC:{CLK_ACTIVE,CLK_PAUSE,CLK_NAP,CLK_SLEEP,CLK_STOP}    //Powerdown modes.
; Description of Function: Sets a powerdown mode for the part.
; User interface: Set iPC to the required power control (PC) mode.
;           0 = CLK_ACTIVE = All parts powered.
;           1 = CLK_PAUSE = Core halted,
;           2 = CLK_NAP = Peripherals also halted,
;           3 = CLK_SLEEP = PLL also halted.
;           4 = CLK_STOP = Only GPIO IRQ powered.
;           5,6,7 = Unused = All parts powered.
;           Call ClkPow().
;               Selected powerdown is set.
;       Returns 1 if iPC<5.
; Robustness:  See part documentation for details of reactivation
;               after powerdown.
; Side effects: Corrupts r1 and r2.

                RSEG CODE
                MODULE ClkPow
                PUBLIC ClkPow
                CODE32
   
ClkPow: mov     r1,r0,LSL#4             ;Position PC bits.
        mov     r0,#0                   ;Default return.
        cmp     r1,#0x50
        bhi     RClkP
        mov     r0,#0xff0000            ;r0 = Z_BASE;
        orr     r0,r0,#0xff000000
        ldr     r2,[r0,#Z_POWCON]       ;Get POWCON
        and     r2,r2,#0x0f             ; remove old PC
        orr     r1,r1,r2                ; and add new PC.
        mov     r2,#1                   ;Write values with keys.
        str     r2,[r0,#Z_POWKEY1]
        str     r1,[r0,#Z_POWCON]
        mov     r2,#0xf4
        str     r2,[r0,#Z_POWKEY2]
        mov     r0,#1                   ;Good return.
RClkP:  bx      lr                      ;return


                 ENDMOD  ClkPow

                 END
                

